@@ -131,15 +131,15 @@ void gaa_help()
 	__gaa_helpsingle(0, "list", "", "Print a list of the supported algorithms  and modes.");
 	__gaa_helpsingle(0, "keymodeslist", "", "Print a list of the supported key modes.");
 	__gaa_helpsingle(0, "hashlist", "", "Print a list of the supported hash algorithms.");
-	__gaa_helpsingle('h', "help", "", "prints this help");
+	__gaa_helpsingle(0, "help", "", "prints this help");
 	__gaa_helpsingle('v', "version", "", "prints the version number");
 	__gaa_helpsingle('L', "license", "", "displays license information.");
 
-#line 100 "gaa.skel"
+//#line 100 "gaa.skel"
 }
 /* Copy of C area */
 
-#line 104 "gaa.skel"
+//#line 104 "gaa.skel"
 /* GAA HEADER */
 #ifndef GAA_HEADER_POKY
 #define GAA_HEADER_POKY
@@ -148,68 +148,68 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 96 "mcrypt.gaa"
+//#line 96 "mcrypt.gaa"
 	char **input;
-#line 95 "mcrypt.gaa"
+//#line 95 "mcrypt.gaa"
 	int size;
-#line 86 "mcrypt.gaa"
+//#line 86 "mcrypt.gaa"
 	char *hash;
-#line 82 "mcrypt.gaa"
+//#line 82 "mcrypt.gaa"
 	char *mode;
-#line 77 "mcrypt.gaa"
+//#line 77 "mcrypt.gaa"
 	char **keys;
-#line 76 "mcrypt.gaa"
+//#line 76 "mcrypt.gaa"
 	int keylen;
-#line 70 "mcrypt.gaa"
+//#line 70 "mcrypt.gaa"
 	char *algorithm;
-#line 67 "mcrypt.gaa"
+//#line 67 "mcrypt.gaa"
 	char *config_file;
-#line 66 "mcrypt.gaa"
+//#line 66 "mcrypt.gaa"
 	int config;
-#line 63 "mcrypt.gaa"
+//#line 63 "mcrypt.gaa"
 	char *keyfile;
-#line 59 "mcrypt.gaa"
+//#line 59 "mcrypt.gaa"
 	int unlink_flag;
-#line 56 "mcrypt.gaa"
+//#line 56 "mcrypt.gaa"
 	char *kmode;
-#line 52 "mcrypt.gaa"
+//#line 52 "mcrypt.gaa"
 	char *modes_directory;
-#line 49 "mcrypt.gaa"
+//#line 49 "mcrypt.gaa"
 	char *algorithms_directory;
-#line 46 "mcrypt.gaa"
+//#line 46 "mcrypt.gaa"
 	int keysize;
-#line 43 "mcrypt.gaa"
+//#line 43 "mcrypt.gaa"
 	int ed_specified;
-#line 42 "mcrypt.gaa"
+//#line 42 "mcrypt.gaa"
 	int ein;
-#line 41 "mcrypt.gaa"
+//#line 41 "mcrypt.gaa"
 	int din;
-#line 38 "mcrypt.gaa"
+//#line 38 "mcrypt.gaa"
 	int double_check;
-#line 35 "mcrypt.gaa"
+//#line 35 "mcrypt.gaa"
 	int flush;
-#line 31 "mcrypt.gaa"
+//#line 31 "mcrypt.gaa"
 	int nodelete;
-#line 28 "mcrypt.gaa"
+//#line 28 "mcrypt.gaa"
 	int noiv;
-#line 25 "mcrypt.gaa"
+//#line 25 "mcrypt.gaa"
 	int noecho;
-#line 22 "mcrypt.gaa"
+//#line 22 "mcrypt.gaa"
 	int nolock;
-#line 19 "mcrypt.gaa"
+//#line 19 "mcrypt.gaa"
 	int bzipflag;
-#line 16 "mcrypt.gaa"
+//#line 16 "mcrypt.gaa"
 	int gzipflag;
-#line 13 "mcrypt.gaa"
+//#line 13 "mcrypt.gaa"
 	int bare_flag;
-#line 10 "mcrypt.gaa"
+//#line 10 "mcrypt.gaa"
 	int real_random_flag;
-#line 7 "mcrypt.gaa"
+//#line 7 "mcrypt.gaa"
 	int force;
-#line 3 "mcrypt.gaa"
+//#line 3 "mcrypt.gaa"
 	int quiet;
 
-#line 114 "gaa.skel"
+//#line 114 "gaa.skel"
 };
 
 #ifdef __cplusplus
@@ -230,7 +230,7 @@ extern "C"
 
 #endif
 
-#line 135 "gaa.skel"
+//#line 135 "gaa.skel"
 
 /* C declarations */
 
@@ -295,7 +295,7 @@ int gaa_error = 0;
 #define GAAOPTID_quiet	30
 #define GAAOPTID_verbose	31
 
-#line 168 "gaa.skel"
+//#line 168 "gaa.skel"
 
 #define GAA_CHECK1STR(a,b)      \
 if(a[0] == str[0])              \
@@ -378,7 +378,11 @@ if(num == 0)                                                        \
 if(!OK) \
 { \
 num = 0;                                                            \
-target = malloc((gaa_last_non_option - gaa_index) * sizeof(type));  \
+if ((gaa_last_non_option - gaa_index) * sizeof(type) > 0) { \
+	target = malloc((gaa_last_non_option - gaa_index) * sizeof(type)); \
+} else { \
+	target=NULL; \
+} \
 for(; gaa_index < gaa_last_non_option; gaa_index++)                 \
 {                                                                   \
     if(gaa_arg_used[gaa_index] == 0)                                \
@@ -543,7 +547,7 @@ struct GAAREST
 	int size1;
 };
          
-#line 349 "gaa.skel"
+//#line 349 "gaa.skel"
 int gaa_is_an_argument(char *str)
 {
 #ifdef GAA_WIN32
@@ -583,10 +587,10 @@ int gaa_get_option_num(char *str, int status)
 			GAA_CHECK1STR("", GAAOPTID_algorithms_directory);
 			GAA_CHECK1STR("s", GAAOPTID_keysize);
         case GAA_MULTIPLE_OPTION:
-#line 375 "gaa.skel"
+//#line 375 "gaa.skel"
 			GAA_CHECK1STR("L", GAAOPTID_license);
 			GAA_CHECK1STR("v", GAAOPTID_version);
-			GAA_CHECK1STR("h", GAAOPTID_help);
+			GAA_CHECK1STR("", GAAOPTID_help);
 			GAA_CHECK1STR("", GAAOPTID_hashlist);
 			GAA_CHECK1STR("", GAAOPTID_keymodeslist);
 			GAA_CHECK1STR("", GAAOPTID_list);
@@ -606,7 +610,7 @@ int gaa_get_option_num(char *str, int status)
 			GAA_CHECK1STR("q", GAAOPTID_quiet);
 			GAA_CHECK1STR("V", GAAOPTID_verbose);
 
-#line 277 "gaa.skel"
+//#line 277 "gaa.skel"
         break;
         case GAA_WORD_OPTION:
 			GAA_CHECKSTR("license", GAAOPTID_license);
@@ -641,7 +645,7 @@ int gaa_get_option_num(char *str, int status)
 			GAA_CHECKSTR("quiet", GAAOPTID_quiet);
 			GAA_CHECKSTR("verbose", GAAOPTID_verbose);
 
-#line 281 "gaa.skel"
+//#line 281 "gaa.skel"
 	break;
         default: break;
         }
@@ -663,7 +667,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 	struct GAAOPTION_algorithms_directory GAATMP_algorithms_directory;
 	struct GAAOPTION_keysize GAATMP_keysize;
 
-#line 393 "gaa.skel"
+//#line 393 "gaa.skel"
 #ifdef GAA_REST_EXISTS
     struct GAAREST GAAREST_tmp;
 #endif
@@ -684,42 +688,42 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
     {
 	case GAAOPTID_license:
 	OK = 0;
-#line 93 "mcrypt.gaa"
+//#line 93 "mcrypt.gaa"
 { mcrypt_license(); exit(0); ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_version:
 	OK = 0;
-#line 92 "mcrypt.gaa"
+//#line 92 "mcrypt.gaa"
 { mcrypt_version(); exit(0); ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_help:
 	OK = 0;
-#line 91 "mcrypt.gaa"
+//#line 91 "mcrypt.gaa"
 { usage(); exit(0); ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_hashlist:
 	OK = 0;
-#line 90 "mcrypt.gaa"
+//#line 90 "mcrypt.gaa"
 { print_hashlist(); exit(0); ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_keymodeslist:
 	OK = 0;
-#line 89 "mcrypt.gaa"
+//#line 89 "mcrypt.gaa"
 { print_keylist(); exit(0); ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_list:
 	OK = 0;
-#line 88 "mcrypt.gaa"
+//#line 88 "mcrypt.gaa"
 { print_list(); exit(0); ;};
 
 		return GAA_OK;
@@ -729,7 +733,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_hash.arg1, gaa_getstr, GAATMP_hash.size1);
 		gaa_index++;
-#line 87 "mcrypt.gaa"
+//#line 87 "mcrypt.gaa"
 { gaaval->hash = GAATMP_hash.arg1 ;};
 
 		return GAA_OK;
@@ -739,7 +743,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_mode.arg1, gaa_getstr, GAATMP_mode.size1);
 		gaa_index++;
-#line 83 "mcrypt.gaa"
+//#line 83 "mcrypt.gaa"
 { gaaval->mode = GAATMP_mode.arg1 ;};
 
 		return GAA_OK;
@@ -747,7 +751,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 	case GAAOPTID_key:
 	OK = 0;
 		GAA_LIST_FILL(GAATMP_key.arg1, gaa_getstr, char*, GAATMP_key.size1);
-#line 78 "mcrypt.gaa"
+//#line 78 "mcrypt.gaa"
 { gaaval->keys = GAATMP_key.arg1; gaaval->keylen = GAATMP_key.size1 ;};
 
 		return GAA_OK;
@@ -757,7 +761,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_algorithm.arg1, gaa_getstr, GAATMP_algorithm.size1);
 		gaa_index++;
-#line 71 "mcrypt.gaa"
+//#line 71 "mcrypt.gaa"
 { gaaval->algorithm = GAATMP_algorithm.arg1 ;};
 
 		return GAA_OK;
@@ -767,7 +771,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_config.arg1, gaa_getstr, GAATMP_config.size1);
 		gaa_index++;
-#line 68 "mcrypt.gaa"
+//#line 68 "mcrypt.gaa"
 { gaaval->config=1; if (GAATMP_config.size1==1) gaaval->config_file = GAATMP_config.arg1 ;};
 
 		return GAA_OK;
@@ -777,14 +781,14 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_keyfile.arg1, gaa_getstr, GAATMP_keyfile.size1);
 		gaa_index++;
-#line 64 "mcrypt.gaa"
+//#line 64 "mcrypt.gaa"
 { gaaval->keyfile = GAATMP_keyfile.arg1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_unlink:
 	OK = 0;
-#line 60 "mcrypt.gaa"
+//#line 60 "mcrypt.gaa"
 { gaaval->unlink_flag = 1 ;};
 
 		return GAA_OK;
@@ -794,7 +798,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_keymode.arg1, gaa_getstr, GAATMP_keymode.size1);
 		gaa_index++;
-#line 57 "mcrypt.gaa"
+//#line 57 "mcrypt.gaa"
 { gaaval->kmode = GAATMP_keymode.arg1 ;};
 
 		return GAA_OK;
@@ -804,7 +808,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_modes_directory.arg1, gaa_getstr, GAATMP_modes_directory.size1);
 		gaa_index++;
-#line 53 "mcrypt.gaa"
+//#line 53 "mcrypt.gaa"
 { gaaval->modes_directory = GAATMP_modes_directory.arg1 ;};
 
 		return GAA_OK;
@@ -814,7 +818,7 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_algorithms_directory.arg1, gaa_getstr, GAATMP_algorithms_directory.size1);
 		gaa_index++;
-#line 50 "mcrypt.gaa"
+//#line 50 "mcrypt.gaa"
 { gaaval->algorithms_directory = GAATMP_algorithms_directory.arg1 ;};
 
 		return GAA_OK;
@@ -824,118 +828,118 @@ int gaa_try(int gaa_num, int gaa_index, gaainfo *gaaval, char *opt_list)
 		GAA_TESTMOREARGS;
 		GAA_FILL(GAATMP_keysize.arg1, gaa_getint, GAATMP_keysize.size1);
 		gaa_index++;
-#line 47 "mcrypt.gaa"
+//#line 47 "mcrypt.gaa"
 { gaaval->keysize = GAATMP_keysize.arg1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_decrypt:
 	OK = 0;
-#line 44 "mcrypt.gaa"
+//#line 44 "mcrypt.gaa"
 { gaaval->ed_specified=1; gaaval->din = 1; gaaval->ein=0; ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_doublecheck:
 	OK = 0;
-#line 39 "mcrypt.gaa"
+//#line 39 "mcrypt.gaa"
 { gaaval->double_check = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_flush:
 	OK = 0;
-#line 36 "mcrypt.gaa"
+//#line 36 "mcrypt.gaa"
 { gaaval->flush = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_nodelete:
 	OK = 0;
-#line 32 "mcrypt.gaa"
+//#line 32 "mcrypt.gaa"
 { gaaval->nodelete = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_noiv:
 	OK = 0;
-#line 29 "mcrypt.gaa"
+//#line 29 "mcrypt.gaa"
 { gaaval->noiv = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_echo:
 	OK = 0;
-#line 26 "mcrypt.gaa"
+//#line 26 "mcrypt.gaa"
 { gaaval->noecho = 0 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_nolock:
 	OK = 0;
-#line 23 "mcrypt.gaa"
+//#line 23 "mcrypt.gaa"
 { gaaval->nolock = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_bzip2:
 	OK = 0;
-#line 20 "mcrypt.gaa"
+//#line 20 "mcrypt.gaa"
 { gaaval->bzipflag = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_gzip:
 	OK = 0;
-#line 17 "mcrypt.gaa"
+//#line 17 "mcrypt.gaa"
 { gaaval->gzipflag = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_bare:
 	OK = 0;
-#line 14 "mcrypt.gaa"
+//#line 14 "mcrypt.gaa"
 { gaaval->bare_flag = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_random:
 	OK = 0;
-#line 11 "mcrypt.gaa"
+//#line 11 "mcrypt.gaa"
 { gaaval->real_random_flag = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_force:
 	OK = 0;
-#line 8 "mcrypt.gaa"
+//#line 8 "mcrypt.gaa"
 { gaaval->force = 1 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_quiet:
 	OK = 0;
-#line 5 "mcrypt.gaa"
+//#line 5 "mcrypt.gaa"
 { gaaval->quiet = 2 ;};
 
 		return GAA_OK;
 		break;
 	case GAAOPTID_verbose:
 	OK = 0;
-#line 4 "mcrypt.gaa"
+//#line 4 "mcrypt.gaa"
 { gaaval->quiet = 0 ;};
 
 		return GAA_OK;
 		break;
 	case GAA_REST:
 		GAA_OPTIONALLIST_FILL(GAAREST_tmp.arg1, gaa_getstr, char*, GAAREST_tmp.size1);
-#line 97 "mcrypt.gaa"
+//#line 97 "mcrypt.gaa"
 { gaaval->input = GAAREST_tmp.arg1; gaaval->size = GAAREST_tmp.size1 ;};
 
 		return GAA_OK;
 		break;
 
-#line 413 "gaa.skel"
+//#line 413 "gaa.skel"
     default: break;
     }
     return GAA_ERROR_UNKNOWN;
@@ -957,7 +961,7 @@ int gaa(int argc, char **argv, gaainfo *gaaval)
     if(inited == 0)
     {
 
-#line 99 "mcrypt.gaa"
+//#line 99 "mcrypt.gaa"
 { gaaval->force=0; gaaval->quiet=1; gaaval->real_random_flag=0; gaaval->config=0;
        gaaval->bare_flag = 0; gaaval->din = 0; gaaval->ein=1; gaaval->unlink_flag = 0;
        gaaval->kmode = NULL; gaaval->keylen=0; gaaval->gzipflag=0; gaaval->bzipflag=0;
@@ -969,7 +973,7 @@ int gaa(int argc, char **argv, gaainfo *gaaval)
 
     }
     inited = 1;
-#line 438 "gaa.skel"
+//#line 438 "gaa.skel"
     gaa_arg_used = malloc(argc * sizeof(char));
     for(i = 1; i < argc; i++)
         gaa_arg_used[i] = 0;
@@ -1041,7 +1045,7 @@ if(gaa_processing_file == 0)
 	GAA_INCOMP("Vq");
 	GAA_INCOMP("kf");
 
-#line 507 "gaa.skel"
+//#line 507 "gaa.skel"
 #ifdef GAA_REST_EXISTS
     switch(gaa_try(GAA_REST, 1, gaaval, opt_list))
     {
