@@ -19,7 +19,7 @@
  */
 
 
-/* $Id: mcrypt.c,v 1.4 2000/09/28 12:03:18 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.5 2000/12/17 13:14:27 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -37,7 +37,7 @@
 
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.4 2000/09/28 12:03:18 nmav Exp $";
+    "$Id: mcrypt.c,v 1.5 2000/12/17 13:14:27 nmav Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -140,7 +140,7 @@ void usage(void)
 #endif
 
 	fprintf(stdout, _("\n"
-			  " -h --help                    prints this help\n"
+			  "    --help                    prints this help\n"
 			  " -v --version                 prints the version number\n"
 			  "\n"
 			  "Report bugs to mcrypt-dev@argeas.cs-net.gr.\n\n"));
